==> android-2.1.0-sources.jar: io/primer/android/domain/payments/create/CreatePaymentInteractor.kt <==
package io.primer.android.domain.payments.create

import io.primer.android.domain.base.BaseErrorEventResolver
import io.primer.android.domain.base.BaseInteractor
import io.primer.android.domain.error.ErrorMapperType
import io.primer.android.domain.payments.helpers.PaymentResultEventsResolver
import io.primer.android.domain.payments.create.model.CreatePaymentParams
import io.primer.android.domain.payments.create.repository.CreatePaymentsRepository
import kotlinx.coroutines.CoroutineDispatcher
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.catch
import kotlinx.coroutines.flow.flowOn
import kotlinx.coroutines.flow.map
import kotlinx.coroutines.flow.onEach

internal class CreatePaymentInteractor(
    private val createPaymentsRepository: CreatePaymentsRepository,
    private val paymentResultEventsResolver: PaymentResultEventsResolver,
    private val errorEventResolver: BaseErrorEventResolver,
    private val dispatcher: CoroutineDispatcher = Dispatchers.IO
) : BaseInteractor<String, CreatePaymentParams>() {

    override fun execute(params: CreatePaymentParams): Flow<String> {
        return createPaymentsRepository.createPayment(params.token)
            .onEach {
                paymentResultEventsResolver.resolve(it, params.resumeHandler)
            }
            .catch {
                errorEventResolver.resolve(it, ErrorMapperType.PAYMENT_CREATE)
            }
            .flowOn(dispatcher)
            .map { it.payment.id }
    }
}

==> android-2.4.0-sources.jar: io/primer/android/domain/payments/create/CreatePaymentInteractor.kt <==
package io.primer.android.domain.payments.create

import io.primer.android.domain.base.BaseErrorEventResolver
import io.primer.android.domain.base.BaseFlowInteractor
import io.primer.android.domain.error.ErrorMapperType
import io.primer.android.domain.payments.helpers.PaymentResultEventsResolver
import io.primer.android.domain.payments.create.model.CreatePaymentParams
import io.primer.android.domain.payments.create.repository.CreatePaymentsRepository
import kotlinx.coroutines.CoroutineDispatcher
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.catch
import kotlinx.coroutines.flow.flowOn
import kotlinx.coroutines.flow.map
import kotlinx.coroutines.flow.onEach

internal class CreatePaymentInteractor(
    private val createPaymentsRepository: CreatePaymentsRepository,
    private val paymentResultEventsResolver: PaymentResultEventsResolver,
    private val errorEventResolver: BaseErrorEventResolver,
    private val dispatcher: CoroutineDispatcher = Dispatchers.IO
) : BaseFlowInteractor<String, CreatePaymentParams>() {

    override fun execute(params: CreatePaymentParams): Flow<String> {
        return createPaymentsRepository.createPayment(params.token)
            .onEach {
                paymentResultEventsResolver.resolve(it, params.resumeHandler)
            }
            .catch {
                errorEventResolver.resolve(it, ErrorMapperType.PAYMENT_CREATE)
            }
            .flowOn(dispatcher)
            .map { it.payment.id }
    }
}
